| Package name                                                  | Package hash                                                  | Description                                                                                                                |
| ------------------------------------------------------------- | ------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------- |
| protocol/valory/abci/0.1.0                                    | `bafybeiak4pwac3pwjtd7weskxdhkrcopckr32vtazfbuteu6yqjkwarpte` | A protocol for ABCI requests and responses.                                                                                |
| protocol/valory/tendermint/0.1.0                              | `bafybeihzb7e32f7jcrzvubilqaxzmyk7ea6ss3pg3tliatdlrr76qeknyq` | A protocol for communication between two AEAs to share tendermint configuration details.                                   |
| protocol/valory/ipfs/0.1.0                                    | `bafybeibz5xqhxdbuvba7nuw2w6ardjermtcoqercopnypdplnaekf3joam` | A protocol specification for IPFS requests and responses.                                                                  |
| protocol/valory/acn_data_share/0.1.0                          | `bafybeieqisfr6lhaaesq37lk7vyaxza2h6nucshksgyo2djqfyf2saqo4i` | A protocol for sharing raw data using ACN.                                                                                 |
| contract/valory/gnosis_safe_proxy_factory/0.1.0               | `bafybeic5qrqbpaucbmiegaxmtvej6n77t32xhepjjunwjxnj6vnayhimde` | Gnosis Safe proxy factory (GnosisSafeProxyFactory) contract                                                                |
| contract/valory/component_registry/0.1.0                      | `bafybeibjwp64gf747c2f5e5pdth753onqemf3yksd3o7724ks3okdwrlli` | Component registry contract                                                                                                |
| contract/valory/agent_registry/0.1.0                          | `bafybeigw66maofg3hlbddt3wugcwtdai7cmwnmk4uvbgu6njusegck6ut4` | Agent registry contract                                                                                                    |
| contract/valory/registries_manager/0.1.0                      | `bafybeicxp34be6nidi64mym4vfuygrdmrwywiwm464pzxdwbww27bwkxjq` | Registries Manager contract                                                                                                |
| contract/valory/service_manager/0.1.0                         | `bafybeigsbp62rhknhknn5zxk53orhhd2p5zrnvntnd37hphwrgoixkuepq` | Service Manager contract                                                                                                   |
| contract/valory/service_registry/0.1.0                        | `bafybeigz6xsbg3nafjhh5pspzqyszndakhxuns4gaqerqxqs5ulmv7d42e` | Service Registry contract                                                                                                  |
| contract/valory/gnosis_safe/0.1.0                             | `bafybeib3ouohbtmhsvqtrmie76vs54bvgdnrn4nes2xkobpksodzdk3owe` | Gnosis Safe (GnosisSafeL2) contract                                                                                        |
| contract/valory/multisend/0.1.0                               | `bafybeiaf3hapi3prgpjeugwhq64k7lqelo6kibhol5rkajt7id3knomp5q` | MultiSend contract                                                                                                         |
| contract/valory/erc20/0.1.0                                   | `bafybeids2etgjos7dttose4plhmpri57zxuks3uv4kxxw56rqsp3renxuu` | The scaffold contract scaffolds a contract to be implemented by the developer.                                             |
| contract/valory/recovery_module/0.1.0                         | `bafybeibyrqo3qshpmgmbsq7eyvj6zxmlil62ndawxwgfp6ylrn7w5com3e` | Recovery module                                                                                                            |
| contract/valory/service_registry_token_utility/0.1.0          | `bafybeiff5qt664ym4rjoyvgysfh6e4sw2sxjbkz6aqaecm4fi5evj3rfbe` | The scaffold contract scaffolds a contract to be implemented by the developer.                                             |
| contract/valory/squads_multisig/0.1.0                         | `bafybeihyxvvbmyw66j7inmd4mdu3vxtyx2hfgxp4mmw624ixe3fywavkfa` | The scaffold contract scaffolds a contract to be implemented by the developer.                                             |
| contract/valory/multicall2/0.1.0                              | `bafybeibaetvueos4hp7dp4t7q4hcpoqmcgjv6g44r2zrosyduj2u3qauha` | The MakerDAO multicall2 contract.                                                                                          |
| contract/valory/poly_safe_creator_with_recovery_module/0.1.0  | `bafybeihg7yb5dk76xecw3n65lmeqb6fssxal2h4kgcrfnwzavhjizqehaa` | PolySafe creator with recovery module                                                                                      |
| contract/valory/sign_message_lib/0.1.0                        | `bafybeif4z7pi4bbrnvf37jzun3b4b72qmcmdr7iuxztz2lu7mka3tz7zea` | SignMessageLib contract                                                                                                    |
| contract/valory/erc8004_identity_registry/0.1.0               | `bafybeictubehcxi7akbfq53g3j3fjdrdupaj5lg66dv7562yays6x63o6q` | ERC8004 Identity Registry contract                                                                                         |
| contract/valory/erc8004_identity_registry_bridger/0.1.0       | `bafybeihlnpbuiunjrh7f7k76bicosnbsabujjkx2y5w7fdfkkscox4chnm` | ERC8004 Identity Registry Bridger contract                                                                                 |
| contract/valory/staking_activity_checker/0.1.0                | `bafybeifsqjqlywsrc5fklj3yuji7twt5sa54r65c7gz4nez4kegi645nze` | Staking activity checker contract                                                                                          |
| contract/valory/staking_token/0.1.0                           | `bafybeig5kyul457aqegcygz4bmnmp6fuiunofzvvkwknknxgkqtz7h2qrq` | Service staking token contract                                                                                             |
| contract/valory/agent_mech/0.1.0                              | `bafybeibdzvnnlrvobnyje7lce7cwsjakurqs274ql2jlpgwkcw4nw7rdsq` | Agent Mech contract.                                                                                                       |
| contract/valory/mech_marketplace/0.1.0                        | `bafybeif4fwtcxipnd4egiwnjgu3zt276ooy623rn4hx7gwrjyycnvm46fi` | Mech Marketplace contract.                                                                                                 |
| connection/valory/abci/0.1.0                                  | `bafybeicpbhxg7sskmh7fgykfl7aixa3pjezcmqcjlso7qy4dc3qve5qkju` | connection to wrap communication with an ABCI server.                                                                      |
| connection/valory/ipfs/0.1.0                                  | `bafybeifid7nlalrgqphdxpg6p3rzlrinzgis5ecz2zk62dqk4xzgrc56mm` | A connection responsible for uploading and downloading files from IPFS.                                                    |
| skill/valory/test_ipfs_abci/0.1.0                             | `bafybeih7y5mjytmh3me2lwtzfcumtp3m63uag7adjcbwq7s7tzbaykvb5y` | IPFS e2e testing application.                                                                                              |
| skill/valory/abstract_abci/0.1.0                              | `bafybeidds7kmntbriicm6gdsk266qjvq3w6aylwqein5xrmotcjsftkhhy` | The abci skill provides a template of an ABCI application.                                                                 |
| skill/valory/abstract_round_abci/0.1.0                        | `bafybeifbnsn2j6yul3k3yh7jgrqkpmqdmdug4yzagl243ashb3imjvdqge` | abstract round-based ABCI application                                                                                      |
| skill/valory/transaction_settlement_abci/0.1.0                | `bafybeihtzblckl32n4vj42pojihavagyuzxqxdfmfchwv2awll6blcgzgm` | ABCI application for transaction settlement.                                                                               |
| skill/valory/registration_abci/0.1.0                          | `bafybeif6rxo7lj3ptctxdbo2hyr3qw6q7obqwwgbxum62fc3u3aiwl4lhu` | ABCI application for common apps.                                                                                          |
| skill/valory/reset_pause_abci/0.1.0                           | `bafybeidr2q2klwa4wrwcpsgcg5nhkqeiuvi6g7rea5rl46hadzd5rbtb5y` | ABCI application for resetting and pausing app executions.                                                                 |
| skill/valory/termination_abci/0.1.0                           | `bafybeib4b7zrjcbok5mrt6yxlw53rn6txyexyjynyplmjtgycppnxuemzy` | Termination skill.                                                                                                         |
| skill/valory/counter/0.1.0                                    | `bafybeihfxy4ik2qhdar5eaq3ug5wruwlxw5hstajmewgefdrkmqroqztwm` | The ABCI Counter application example.                                                                                      |
| skill/valory/counter_client/0.1.0                             | `bafybeictnuzwjih3wift5zxfwvyin6zcr2sprv4eyelewusmcc3aiz7nki` | A client for the ABCI counter application.                                                                                 |
| skill/valory/register_reset_abci/0.1.0                        | `bafybeihnowngj6affshivql3pm3p32nzrlmhomhdmpwz7eomt2g4tmzaya` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/register_termination_abci/0.1.0                  | `bafybeibwkjy56lswhj46qdpuftzlaqaqt7hstpx5nmmbdgayhu6drpqa34` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/test_abci/0.1.0                                  | `bafybeicnaics5prj6mtrzp7525uffqlcyvlyhlchmel2ns3axwemmta5wu` | ABCI application for testing the ABCI connection.                                                                          |
| skill/valory/register_reset_recovery_abci/0.1.0               | `bafybeidgjzmst223vngxgimqmqnkeiwthpiauuw5dq6euj22abtknmat4e` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/slashing_abci/0.1.0                              | `bafybeidpgxjov6t5ad3mpsrkjkvbfyonpevls2d543qgwiciay2mv7wrkq` | Slashing skill.                                                                                                            |
| skill/valory/offend_abci/0.1.0                                | `bafybeic3ixqzvtrghrfnbkxguocgg3lkrbcc5dr4uupdqc4e6dduxk4xlu` | Offend ABCI application.                                                                                                   |
| skill/valory/offend_slash_abci/0.1.0                          | `bafybeihxrfr4v2cmbjt4kje2gktz5j5skgfujwy5djzgw5pcgs7pwabaaa` | ABCI application used in order to test the slashing abci                                                                   |
| skill/valory/squads_transaction_settlement_abci/0.1.0         | `bafybeidn3nwjuuk4e3lj4mc5kqoi6wj2tf73utxh7qesd33ydl3ixw4qnq` | ABCI application for transaction settlement.                                                                               |
| skill/valory/test_solana_tx_abci/0.1.0                        | `bafybeicyz6c7cdmkxs47qvbzwhinn2p5bogtt5mwst4zl72kj4knyapquu` | SOLANA e2e testing application.                                                                                            |
| agent/valory/test_ipfs/0.1.0                                  | `bafybeig2kr7klfegj2p2x7ugqzru5ekou6lefrdrtnmqeoov6kscxcgihy` | Agent for testing the ABCI connection.                                                                                     |
| agent/valory/abstract_abci/0.1.0                              | `bafybeigyhe4wzxktf7btsgozve4zqi6adlnzilyhiwrywxarnequumhtqu` | The abstract ABCI AEA - for testing purposes only.                                                                         |
| agent/valory/counter/0.1.0                                    | `bafybeihxlb3jxpzp2lmv3nsbofk3h2u3jyejnfl7utzl37a3mysxwsgi24` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/counter_client/0.1.0                             | `bafybeic6bmdvijzhetpsczoubfb6p7qvjpetybaq2ffoq64o7ju3phkiiy` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/register_reset/0.1.0                             | `bafybeifknlodfpyjkln6joe4bwd5edj2e22znw2xce3436f6ojbvgnrumi` | Register reset to replicate Tendermint issue.                                                                              |
| agent/valory/register_termination/0.1.0                       | `bafybeifjuld7m36lhrkjvujq42nnsnr5eqdgizlrqqshkgl6wauxu2ixl4` | Register terminate to test the termination feature.                                                                        |
| agent/valory/registration_start_up/0.1.0                      | `bafybeihbjpq7ul4xo2pgg6bhsbapfanzgcyvg7jddcpotvjud6z74ikfkq` | Registration start-up ABCI example.                                                                                        |
| agent/valory/test_abci/0.1.0                                  | `bafybeics3smu7nz6n27rsb6rntmkqbg2cjfxbpwe2gfcjbzp4e36u77pou` | Agent for testing the ABCI connection.                                                                                     |
| agent/valory/register_reset_recovery/0.1.0                    | `bafybeicuv63mxjoqfqrihpl2u3atqhh5nl7jnt4xo3lacocofgfgpixw6u` | Agent to showcase hard reset as a recovery mechanism.                                                                      |
| agent/valory/offend_slash/0.1.0                               | `bafybeigpsthkcro2dpxf2czzgdgh3yvum6u4be24po7jqrirqkekxtotxa` | Offend and slash to test the slashing feature.                                                                             |
| agent/valory/solana_transfer_agent/0.1.0                      | `bafybeifggssqhs42mi35vde3g2ge4iysoghhu4luez63azu4icosqixraa` | Register terminate to test the termination feature.                                                                        |
| service/valory/counter/0.1.0                                  | `bafybeidnldkf5aqpztgeigjgdocp2dorbueguqdfz5pl2nvth6hxtuekb4` | A set of agents incrementing a counter                                                                                     |
| service/valory/register_reset/0.1.0                           | `bafybeibokng3ux23k4yeyoareyuakt63byugd5lqex44gasunbgoobzpey` | Test and debug tendermint reset mechanism.                                                                                 |
| protocol/open_aea/signing/1.0.0                               | `bafybeifsjmldwyki3beqyvdt5lzenrg6wyrqaar5plc5rpnvtc4zlentye` | A protocol for communication between skills and decision maker.                                                            |
| protocol/valory/acn/1.1.0                                     | `bafybeiea66z4k6cgcazxd6qzvnkllulyjzbnxufkoenge7qzh4qfogrvoa` | The protocol used for envelope delivery on the ACN.                                                                        |
| protocol/valory/http/1.0.0                                    | `bafybeidxkp3vga7t6x2pbt2tpkgyaxa5bgpdgryao54py7w3yxyzr7neoy` | A protocol for HTTP requests and responses.                                                                                |
| protocol/valory/ledger_api/1.0.0                              | `bafybeiecq56phjfws36rgrefw6niyo4ezesloodsfis647mpm5ygqo4ysi` | A protocol for ledger APIs requests and responses.                                                                         |
| protocol/valory/contract_api/1.0.0                            | `bafybeibld2xb5m7kyluiptkamp4nrt6oeomkohz7a3yppbv2oo7qw2e4la` | A protocol for contract APIs requests and responses.                                                                       |
| connection/valory/http_client/0.23.0                          | `bafybeihel6sg2yayxu7lqygaswdgciaxpqrgsbl5rwx74c6znu5qz2edd4` | The HTTP_client connection that wraps a web-based client connecting to a RESTful API specification.                        |
| connection/valory/ledger/0.19.0                               | `bafybeidxzeygks5zcky4u2ztcdufzptssgf6uqytxofnn6yta7qq6jsim4` | A connection to interact with any ledger API and contract API.                                                             |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeielj3jso3wvrarp5n5rq7llpw4vgxybqiyensgjalb5ubfiawwhhu` | The libp2p client connection implements a tcp connection to a running libp2p node as a traffic delegate to send/receive envelopes to/from agents in the DHT. |
